# Frontend Assets
```bash
pip install git+https://github.com/avryhof/frontend_assets.git
```

This is just a basic package that can be installed in Django to bring in a collection of Front-End libraries I use for many projects.

It also has a base template that you can use to kickstart your project.